# Parser for Talon files in Python

![GitHub Workflow Status](https://img.shields.io/github/workflow/status/wenkokke/py-tree-sitter-talon/CI) ![GitHub tag (latest by date)](https://img.shields.io/github/v/tag/wenkokke/py-tree-sitter-talon) ![PyPI](https://img.shields.io/pypi/v/tree-sitter-talon)
